@@ -1,4 +1,5 @@
 import os
+from datetime import date
 
 import click
 
@@ -22,6 +23,8 @@ def main():
 
   print(proj_number)
 
+  project_name = input("Type in the project name")
+
   stills = os.path.join(cwd, 'Test_Stills')
 
   if not os.path.isdir(stills):
@@ -38,15 +41,26 @@ def main():
   pdf.set_font('Arial', 'B', 16)
 
 
-  files = os.listdir(pov)
+  pdf.add_page()
+  pdf.cell(40,10, 'Animotions')
+  pdf.cell(40,20, 'beyond the visual')
+
+  files = [x for x in os.listdir(pov) if "CAM" in x]
   for f in files:
     pdf.add_page()
-    pdf.cell(40,10,f)
+    camname = os.path.splitext(f)[0]
+    pdf.cell(40,0, project_name)
+    pdf.cell(40,10,camname)
     pdf.cell(40,20, proj_number)
 
   mv = os.path.join(cwd, 'MV')
 
-  pdf.output(mv, 'pov_brief.pdf', 'F')
+  mvs = [int(x[0:1]) for x in os.listdir(mv)]
+
+  print(max(mvs))
+
+  datum = date.today().strftime("%Y%m%d")
+  pdf.output(os.path.join(mv, f'{max(mvs)+1}_{datum}_pov_brief.pdf'), 'F')
 
 
 
